@@ -148,12 +148,12 @@ class GPCM(Ordinal):
             max_iters (int, optional):
                 An `int` to specify the maximal number of iterations for the fitting process, that is,
                 the sum of expectation-maximization (StEM) steps and stochastic approximation (SA) steps.
-                By default, `max_iters` is `600`.
+                By default, `max_iters` is `700`.
             stem_steps (int, optional):
                 An `int` for the number of steps for the stochastic expectation-maximization (StEM) algorithm.
                 StEM is used in the first stage of fitting.
                 Note that `stem_steps` is also counted in `max_iters`.
-                By default, `stem_steps` is `100`.
+                By default, `stem_steps` is `200`.
             warmup_steps (int, optional):
                 An `int` for the number of steps for the warmup steps when intializing MCMC sampling.
                 By default, `warmup_steps` is `150`.
@@ -233,7 +233,7 @@ class GPCM(Ordinal):
             max_cats = params["intercept"].shape[1]
             logit = (eta @ params["loading"].T)[..., None] * jnp.arange(max_cats) + jnp.cumsum(params["intercept"], axis=1)
             cr_prob = jnp.exp(logit)
-            cr_prob = cr_prob / jnp.sum(cr_prob, axis=2)[..., None]
+            cr_prob = cr_prob / jnp.sum(cr_prob, axis=-1)[..., None]
             return cr_prob
 
         self.crf = crf
@@ -257,10 +257,9 @@ class GPCM(Ordinal):
                 for j in range(n_cats, self.info["max_cats"]):
                     row_idx.append(i)
                     col_idx.append(j)
-            self.masks["intercept"] = jax.ops.index_update(
-                x=self.masks["intercept"],
-                idx=(row_idx, col_idx),
-                y=0.)
+            self.masks["intercept"] = self.masks[
+                "intercept"].at[
+                (row_idx, col_idx)].set(0.)
 
     def init_params(self):
         def init_intercept(p1):
@@ -287,7 +286,6 @@ class GPCM(Ordinal):
                 for j in range(n_cats, self.info["max_cats"]):
                     row_idx.append(i)
                     col_idx.append(j)
-            self.params["intercept"] = jax.ops.index_update(
-                x=self.params["intercept"],
-                idx=(row_idx, col_idx),
-                y=-jnp.inf)
\ No newline at end of file
+            self.params["intercept"] = self.params[
+                "intercept"].at[
+                (row_idx, col_idx)].set(-jnp.inf)
\ No newline at end of file
